curly

package module
v0.0.0-...-cd8fa92 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Format

func Format(format string, source interface{}) (string, error)

Format an object into a string based on the format.

Types

type Formatter

type Formatter interface {
	Format(v interface{}) (string, error)
}

Formatter formats an object into a string

func NewFormatter

func NewFormatter(format string, source interface{}) (Formatter, error)

NewFormatter creaets a formatter object that can be reused to format the same objects.

Jump to