package
module
Version:
v0.0.0-...-cd8fa92
Opens a new window with list of versions in this module.
Published: Mar 22, 2022
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Format an object into a string based on the format.
type Formatter interface {
Format(v interface{}) (string, error)
}
Formatter formats an object into a string
NewFormatter creaets a formatter object that can be reused to format the
same objects.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.